
blackhumor = [
    
]

tongue_twister = [
    
]

puns = [
    
]

# ------------------------------------------------------------------------------

# Chanhe this to the language code
language_puns = {
    'blackhumor': blackhumor,
    'tongue_twister': tongue_twister,
    'puns': puns,
    'all': blackhumor + tongue_twister + puns
}
